@@ -921,27 +921,41 @@ static enum si_sm_result smi_event_handler(struct smi_info *smi_info,
 	//	si_sm_result = smi_info->handlers->event(smi_info->si_sm, 0);
 	}
 
-	/* We prefer handling attn over new messages. */
+	/* We prefer handling ATTN  over new messages but
+           ONLY if we are ready to process.*/
 	if (si_sm_result == SI_SM_ATTN)
 	{
-		unsigned char msg[2];
+		if (ipmi_intf_registered(smi_info->intf))
+		{
+			unsigned char msg[2];
 
-		spin_lock(&smi_info->count_lock);
-		smi_info->attentions++;
-		spin_unlock(&smi_info->count_lock);
+			spin_lock(&smi_info->count_lock);
+			smi_info->attentions++;
+			spin_unlock(&smi_info->count_lock);
 
-		/* Got a attn, send down a get message flags to see
-                   what's causing it.  It would be better to handle
-                   this in the upper layer, but due to the way
-                   interrupts work with the SMI, that's not really
-                   possible. */
-		msg[0] = (IPMI_NETFN_APP_REQUEST << 2);
-		msg[1] = IPMI_GET_MSG_FLAGS_CMD;
+			/* Got a attn, send down a get message flags to see
+                   	what's causing it.  It would be better to handle
+                   	this in the upper layer, but due to the way
+                   	interrupts work with the SMI, that's not really
+                   	possible. */
+			msg[0] = (IPMI_NETFN_APP_REQUEST << 2);
+			msg[1] = IPMI_GET_MSG_FLAGS_CMD;
 
-		smi_info->handlers->start_transaction(
-			smi_info->si_sm, msg, 2);
-		smi_info->si_state = SI_GETTING_FLAGS;
-		goto restart;
+			smi_info->handlers->start_transaction(
+				smi_info->si_sm, msg, 2);
+			smi_info->si_state = SI_GETTING_FLAGS;
+			goto restart;
+		}
+		else
+		{
+			/*  Issue with ipmi_register_smi racing to
+			    setup BMC Channels.  */
+			si_sm_result = start_next_msg(smi_info);
+			if (si_sm_result == SI_SM_ATTN)
+				si_sm_result = SI_SM_IDLE;
+
+			return (si_sm_result);
+		}
 	}
 
 	/* If we are currently idle, try to start the next message. */
